@@ -1,6 +1,6 @@
 from adrest.tests.utils import AdrestTestCase
 from django.utils import simplejson
-from milkman.dairy import milkman # nolint
+from mixer.backend.django import mixer
 
 from .api import API
 from .models import Root, Child
@@ -79,14 +79,14 @@ class RPCTestCase(AdrestTestCase):
 
     def test_base(self):
         uri = self.reverse('test')
-        self.assertEqual(uri, '/rpc/test/')
+        self.assertEqual(uri, '/rpc/1.0.0/test/')
 
         response = self.get_resource('test')
         self.assertContains(response, 'true')
 
     def test_autojsonrpc(self):
         uri = self.reverse('autojsonrpc')
-        self.assertEqual(uri, '/rpc/rpc')
+        self.assertEqual(uri, '/rpc/1.0.0/rpc')
 
         response = self.get_resource('autojsonrpc')
         self.assertContains(response, 'Invalid RPC Call.')
@@ -110,7 +110,7 @@ class RPCTestCase(AdrestTestCase):
             'autojsonrpc',
             rpc=dict(
             method='test.bla'))
-        self.assertContains(response, 'unsupported method')
+        self.assertContains(response, 'not allowed')
 
         response = self.rpc(
             'autojsonrpc',
@@ -207,7 +207,7 @@ class RPCTestCase(AdrestTestCase):
         self.assertContains(response, 'test1234')
 
     def test_custom(self):
-        milkman.deliver('rpc.custom')
+        mixer.blend('rpc.custom')
         response = self.rpc(
             'autojsonrpc',
             rpc=dict(method='custom.get'))
@@ -231,3 +231,5 @@ class RPCTestCase(AdrestTestCase):
                 method='__private_method',
             ))
         self.assertContains(response, 'error')
+
+# lint_ignore=C,F0401
